@@ -26,21 +26,21 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             data1 = list(Test.objects.all())
         self.assertListEqual(data1, [])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t1 = Test.objects.create(name='test1')
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t2 = Test.objects.create(name='test2')
 
         with self.assertNumQueries(1):
             data2 = list(Test.objects.all())
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t3 = Test.objects.create(name='test3')
         with self.assertNumQueries(1):
             data3 = list(Test.objects.all())
         self.assertListEqual(data2, [t1, t2])
         self.assertListEqual(data3, [t1, t2, t3])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t3_copy = Test.objects.create(name='test3')
         self.assertNotEqual(t3_copy, t3)
         with self.assertNumQueries(1):
@@ -126,12 +126,12 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
                              ['test%02d' % (i // 2) for i in range(2, 22)])
 
     def test_update(self):
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t = Test.objects.create(name='test1')
 
         with self.assertNumQueries(1):
             t1 = Test.objects.get()
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t.name = 'test2'
             t.save()
         with self.assertNumQueries(1):
@@ -139,21 +139,21 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
         self.assertEqual(t1.name, 'test1')
         self.assertEqual(t2.name, 'test2')
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.update(name='test3')
         with self.assertNumQueries(1):
             t3 = Test.objects.get()
         self.assertEqual(t3.name, 'test3')
 
     def test_delete(self):
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t1 = Test.objects.create(name='test1')
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t2 = Test.objects.create(name='test2')
 
         with self.assertNumQueries(1):
             data1 = list(Test.objects.values_list('name', flat=True))
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t2.delete()
         with self.assertNumQueries(1):
             data2 = list(Test.objects.values_list('name', flat=True))
@@ -176,7 +176,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
 
         Test.objects.create(name='test')
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             self.assertTrue(Test.objects.create())
 
     def test_invalidate_count(self):
@@ -314,22 +314,22 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
         with self.assertNumQueries(1):
             self.assertEqual(User.objects.aggregate(n=Count('test'))['n'], 0)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             u = User.objects.create_user('test')
         with self.assertNumQueries(1):
             self.assertEqual(User.objects.aggregate(n=Count('test'))['n'], 0)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test1')
         with self.assertNumQueries(1):
             self.assertEqual(User.objects.aggregate(n=Count('test'))['n'], 0)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test2', owner=u)
         with self.assertNumQueries(1):
             self.assertEqual(User.objects.aggregate(n=Count('test'))['n'], 1)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test3')
         with self.assertNumQueries(1):
             self.assertEqual(User.objects.aggregate(n=Count('test'))['n'], 1)
@@ -339,13 +339,13 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             data1 = list(User.objects.annotate(n=Count('test')).order_by('pk'))
         self.assertListEqual(data1, [])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test1')
         with self.assertNumQueries(1):
             data2 = list(User.objects.annotate(n=Count('test')).order_by('pk'))
         self.assertListEqual(data2, [])
 
-        with self.assertNumQueries(4 if self.is_dj_21_below_and_is_sqlite() else 2):
+        with self.assertNumQueries(2):
             user1 = User.objects.create_user('user1')
             user2 = User.objects.create_user('user2')
         with self.assertNumQueries(1):
@@ -353,7 +353,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
         self.assertListEqual(data3, [user1, user2])
         self.assertListEqual([u.n for u in data3], [0, 0])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test2', owner=user1)
         with self.assertNumQueries(1):
             data4 = list(User.objects.annotate(n=Count('test')).order_by('pk'))
@@ -581,7 +581,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             data1 = list(Test.objects.select_related('owner'))
         self.assertListEqual(data1, [])
 
-        with self.assertNumQueries(4 if self.is_dj_21_below_and_is_sqlite() else 2):
+        with self.assertNumQueries(2):
             u1 = User.objects.create_user('test1')
             u2 = User.objects.create_user('test2')
         with self.assertNumQueries(1):
@@ -615,7 +615,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
                          .prefetch_related('owner__groups__permissions'))
             self.assertListEqual(data1, [])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t1 = Test.objects.create(name='test1')
         with self.assertNumQueries(1):
             data2 = list(Test.objects.select_related('owner')
@@ -623,7 +623,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertListEqual(data2, [t1])
             self.assertEqual(data2[0].owner, None)
 
-        with self.assertNumQueries(4 if self.is_dj_21_below_and_is_sqlite() else 2):
+        with self.assertNumQueries(2):
             u = User.objects.create_user('user')
             t1.owner = u
             t1.save()
@@ -635,8 +635,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertListEqual(list(data3[0].owner.groups.all()), [])
 
         with self.assertNumQueries(
-                9 if self.is_dj_21_below_and_is_sqlite()
-                else 8 if self.is_sqlite and DJANGO_VERSION[0] == 2 and DJANGO_VERSION[1] == 2
+                8 if self.is_sqlite and DJANGO_VERSION[0] == 2 and DJANGO_VERSION[1] == 2
                 else 4 if self.is_postgresql and DJANGO_VERSION[0] > 2
                 else 4 if self.is_mysql and DJANGO_VERSION[0] > 2
                 else 6
@@ -656,7 +655,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertListEqual(list(groups[0].permissions.all()),
                                  permissions)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t2 = Test.objects.create(name='test2')
         with self.assertNumQueries(1):
             data5 = list(Test.objects.select_related('owner')
@@ -670,13 +669,13 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
                                  for p in g.permissions.all()]
             self.assertListEqual(data5_permissions, permissions)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             permissions[0].save()
         with self.assertNumQueries(1):
             list(Test.objects.select_related('owner')
                  .prefetch_related('owner__groups__permissions'))
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             group.name = 'modified_test_group'
             group.save()
         with self.assertNumQueries(2):
@@ -685,7 +684,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             g = list(data6[0].owner.groups.all())[0]
             self.assertEqual(g.name, 'modified_test_group')
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             User.objects.update(username='modified_user')
 
         with self.assertNumQueries(2):
@@ -739,8 +738,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertListEqual(data2, [t1])
             self.assertListEqual([o.username_length for o in data2], [4])
 
-        admin = User.objects.create_superuser('admin',
-                                              'admin@test.me', 'password')
+        admin = User.objects.create_superuser('admin', 'admin@test.me', 'password')
 
         with self.assertNumQueries(1):
             data3 = list(Test.objects.extra(
@@ -757,42 +755,35 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertListEqual([o.username_length for o in data4], [4, 5])
 
     def test_invalidate_having(self):
+        def _query():
+            return User.objects.annotate(n=Count('user_permissions')).filter(n__gte=1)
+
         with self.assertNumQueries(1):
-            data1 = list(User.objects.annotate(n=Count('user_permissions'))
-                         .filter(n__gte=1))
+            data1 = list(_query())
             self.assertListEqual(data1, [])
 
         u = User.objects.create_user('user')
-
         with self.assertNumQueries(1):
-            data2 = list(User.objects.annotate(n=Count('user_permissions'))
-                         .filter(n__gte=1))
+            data2 = list(_query())
             self.assertListEqual(data2, [])
 
         p = Permission.objects.first()
         p.save()
-
         with self.assertNumQueries(1):
-            data3 = list(User.objects.annotate(n=Count('user_permissions'))
-                         .filter(n__gte=1))
+            data3 = list(_query())
             self.assertListEqual(data3, [])
 
         u.user_permissions.add(p)
-
         with self.assertNumQueries(1):
-            data3 = list(User.objects.annotate(n=Count('user_permissions'))
-                         .filter(n__gte=1))
+            data3 = list(_query())
             self.assertListEqual(data3, [u])
 
         with self.assertNumQueries(1):
-            self.assertEqual(User.objects.annotate(n=Count('user_permissions'))
-                             .filter(n__gte=1).count(), 1)
+            self.assertEqual(_query().count(), 1)
 
         u.user_permissions.clear()
-
         with self.assertNumQueries(1):
-            self.assertEqual(User.objects.annotate(n=Count('user_permissions'))
-                             .filter(n__gte=1).count(), 0)
+            self.assertEqual(_query().count(), 0)
 
     def test_invalidate_extra_where(self):
         sql_condition = ("owner_id IN "
@@ -801,47 +792,43 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             data1 = list(Test.objects.extra(where=[sql_condition]))
             self.assertListEqual(data1, [])
 
-        admin = User.objects.create_superuser('admin',
-                                              'admin@test.me', 'password')
-
+        admin = User.objects.create_superuser('admin', 'admin@test.me', 'password')
         with self.assertNumQueries(1):
             data2 = list(Test.objects.extra(where=[sql_condition]))
             self.assertListEqual(data2, [])
 
         t = Test.objects.create(name='test', owner=admin)
-
         with self.assertNumQueries(1):
             data3 = list(Test.objects.extra(where=[sql_condition]))
             self.assertListEqual(data3, [t])
 
         admin.username = 'modified'
         admin.save()
-
         with self.assertNumQueries(1):
             data4 = list(Test.objects.extra(where=[sql_condition]))
             self.assertListEqual(data4, [])
 
     def test_invalidate_extra_tables(self):
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             User.objects.create_user('user1')
 
         with self.assertNumQueries(1):
             data1 = list(Test.objects.all().extra(tables=['auth_user']))
         self.assertListEqual(data1, [])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t1 = Test.objects.create(name='test1')
         with self.assertNumQueries(1):
             data2 = list(Test.objects.all().extra(tables=['auth_user']))
         self.assertListEqual(data2, [t1])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             t2 = Test.objects.create(name='test2')
         with self.assertNumQueries(1):
             data3 = list(Test.objects.all().extra(tables=['auth_user']))
         self.assertListEqual(data3, [t1, t2])
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             User.objects.create_user('user2')
         with self.assertNumQueries(1):
             data4 = list(Test.objects.all().extra(tables=['auth_user']))
@@ -871,7 +858,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
         with self.assertNumQueries(1):
             self.assertEqual(TestChild.objects.get(), t_child)
 
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             TestParent.objects.filter(pk=t_child.pk).update(name='modified')
 
         with self.assertNumQueries(1):
@@ -879,7 +866,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             self.assertEqual(modified_t_child.pk, t_child.pk)
             self.assertEqual(modified_t_child.name, 'modified')
 
-        with self.assertNumQueries(3 if self.is_dj_21_below_and_is_sqlite() else 2):
+        with self.assertNumQueries(2):
             TestChild.objects.filter(pk=t_child.pk).update(name='modified2')
 
         with self.assertNumQueries(1):
@@ -897,7 +884,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             with connection.cursor() as cursor:
                 cursor.execute(
                     "INSERT INTO cachalot_test (name, public) "
-                    "VALUES ('test1', %s)", [1 if self.is_dj_21_below_and_is_sqlite() else True])
+                    "VALUES ('test1', %s)", [True])
 
         with self.assertNumQueries(1):
             self.assertListEqual(
@@ -908,7 +895,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             with connection.cursor() as cursor:
                 cursor.execute(
                     "INSERT INTO cachalot_test (name, public) "
-                    "VALUES ('test2', %s)", [1 if self.is_dj_21_below_and_is_sqlite() else True])
+                    "VALUES ('test2', %s)", [True])
 
         with self.assertNumQueries(1):
             self.assertListEqual(
@@ -919,7 +906,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
             with connection.cursor() as cursor:
                 cursor.executemany(
                     "INSERT INTO cachalot_test (name, public) "
-                    "VALUES ('test3', %s)", [[1 if self.is_dj_21_below_and_is_sqlite() else True]])
+                    "VALUES ('test3', %s)", [[True]])
 
         with self.assertNumQueries(1):
             self.assertListEqual(
@@ -927,7 +914,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
                 ['test1', 'test2', 'test3'])
 
     def test_raw_update(self):
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test')
         with self.assertNumQueries(1):
             self.assertListEqual(
@@ -944,7 +931,7 @@ class WriteTestCase(TestUtilsMixin, TransactionTestCase):
                 ['new name'])
 
     def test_raw_delete(self):
-        with self.assertNumQueries(2 if self.is_dj_21_below_and_is_sqlite() else 1):
+        with self.assertNumQueries(1):
             Test.objects.create(name='test')
         with self.assertNumQueries(1):
             self.assertListEqual(
@@ -1026,7 +1013,7 @@ class DatabaseCommandTestCase(TestUtilsMixin, TransactionTestCase):
 
         call_command('flush', verbosity=0, interactive=False)
 
-        self.force_repoen_connection()
+        self.force_reopen_connection()
 
         with self.assertNumQueries(1):
             self.assertListEqual(list(Test.objects.all()), [])
@@ -1038,7 +1025,7 @@ class DatabaseCommandTestCase(TestUtilsMixin, TransactionTestCase):
         call_command('loaddata', 'cachalot/tests/loaddata_fixture.json',
                      verbosity=0)
 
-        self.force_repoen_connection()
+        self.force_reopen_connection()
 
         with self.assertNumQueries(1):
             self.assertListEqual([t.name for t in Test.objects.all()],
