@@ -2,11 +2,13 @@ import datetime
 from decimal import Decimal
 from hashlib import sha1
 from time import time
+from typing import TYPE_CHECKING
 from uuid import UUID
 
 from django.contrib.postgres.functions import TransactionNow
 from django.db import connections
-from django.db.models import QuerySet, Subquery, Exists
+from django.db.models import Exists, QuerySet, Subquery
+from django.db.models.expressions import RawSQL
 from django.db.models.functions import Now
 from django.db.models.sql import Query, AggregateQuery
 from django.db.models.sql.where import ExtraWhere, WhereNode, NothingNode
@@ -15,6 +17,10 @@ from .settings import ITERABLES, cachalot_settings
 from .transaction import AtomicCache
 
 
+if TYPE_CHECKING:
+    from django.db.models.expressions import BaseExpression 
+
+
 class UncachableQuery(Exception):
     pass
 
@@ -118,24 +124,6 @@ def _find_rhs_lhs_subquery(side):
         raise UncachableQuery
 
 
-def _find_rhs_lhs_subquery(side):
-    h_class = side.__class__
-    if h_class is Query:
-        return side
-    elif h_class is QuerySet:
-        return side.query
-    elif h_class in (Subquery, Exists):  # Subquery allows QuerySet & Query
-        try:
-            return side.query.query if side.query.__class__ is QuerySet else side.query
-        except AttributeError:  # TODO Remove try/except closure after drop Django 2.2
-            try:
-                return side.queryset.query
-            except AttributeError:
-                return None
-    elif h_class in UNCACHABLE_FUNCS:
-        raise UncachableQuery
-
-
 def _find_subqueries_in_where(children):
     for child in children:
         child_class = child.__class__
@@ -177,6 +165,23 @@ def filter_cachable(tables):
     return tables
 
 
+def _flatten(expression: "BaseExpression"):
+    """
+    Recursively yield this expression and all subexpressions, in
+    depth-first order.
+
+    Taken from Django 3.2 as the previous Django versions don’t check
+    for existence of flatten.
+    """
+    yield expression
+    for expr in expression.get_source_expressions():
+        if expr:
+            if hasattr(expr, 'flatten'):
+                yield from _flatten(expr)
+            else:
+                yield expr
+
+
 def _get_tables(db_alias, query):
     if query.select_for_update or (
             not cachalot_settings.CACHALOT_CACHE_RANDOM
@@ -189,13 +194,20 @@ def _get_tables(db_alias, query):
         # Gets all tables already found by the ORM.
         tables = set(query.table_map)
         tables.add(query.get_meta().db_table)
+
         # Gets tables in subquery annotations.
         for annotation in query.annotations.values():
-            if isinstance(annotation, Subquery):
-                if hasattr(annotation, "queryset"):
-                    tables.update(_get_tables(db_alias, annotation.queryset.query))
-                else:
-                    tables.update(_get_tables(db_alias, annotation.query))
+            if type(annotation) in UNCACHABLE_FUNCS:
+                raise UncachableQuery
+            for expression in _flatten(annotation):
+                if isinstance(expression, Subquery):
+                    if hasattr(expression, "queryset"):
+                        tables.update(_get_tables(db_alias, expression.queryset.query))
+                    else:
+                        tables.update(_get_tables(db_alias, expression.query))
+                elif isinstance(expression, RawSQL):
+                    sql = expression.as_sql(None, None)[0].lower()
+                    tables.update(_get_tables_from_sql(connections[db_alias], sql))
         # Gets tables in WHERE subqueries.
         for subquery in _find_subqueries_in_where(query.where.children):
             tables.update(_get_tables(db_alias, subquery))
